b=('Qiao','Chou','Bei','Xuan','Wei','Ge','Qian','Wei','Yu','Yu','Bi','Xuan','Huan','Min','Bi','Yi','Mian','Yong','Kai','Dang','Yin','E','Chen','Mao','Qia','Ke','Yu','Ai','Qie','Yan','Nuo','Gan','Yun','Zong','Sai','Leng','Fen','Ying','Kui','Kui','Que','Gong','Yun','Su','Su','Qi','Yao','Song','Huang','Ji','Gu','Ju','Chuang','Ni','Xie','Kai','Zheng','Yong','Cao','Xun','Shen','Bo','Kai','Yuan','Xi','Hun','Yong','Yang','Li','Sao','Tao','Yin','Ci','Xu','Qian','Tai','Huang','Yun','Shen','Ming','Gong','She','Cong','Piao','Mu','Mu','Guo','Chi','Can','Can','Can','Cui','Min','Te','Zhang','Tong','Ao','Shuang','Man','Guan','Que','Zao','Jiu','Hui','Kai','Lian','Ou','Song','Qin','Yin','Lu','Shang','Wei','Tuan','Man','Qian','She','Yong','Qing','Kang','Di','Zhi','Lou','Juan','Qi','Qi','Yu','Ping','Liao','Cong','You','Chong','Zhi','Tong','Cheng','Qi','Qu','Peng','Bei','Bie','Qiong','Jiao','Zeng','Chi','Lian','Ping','Kui','Hui','Qiao','Cheng','Yin','Yin','Xi','Xi','Dan','Tan','Duo','Dui','Dui','Su','Jue','Ce','Xiao','Fan','Fen','Lao','Lao','Chong','Han','Qi','Xian','Min','Jing','Liao','Wu','Can','Jue','Cu','Xian','Tan','Sheng','Pi','Yi','Chu','Xian','Nao','Dan','Tan','Jing','Song','Han','Jiao','Wei','Xuan','Dong','Qin','Qin','Ju','Cao','Ken','Xie','Ying','Ao','Mao','Yi','Lin','Se','Jun','Huai','Men','Lan','Ai','Lin','Yan','Kuo','Xia','Chi','Yu','Yin','Dai','Meng','Ai','Meng','Dui','Qi','Mo','Lan','Men','Chou','Zhi','Nuo','Nuo','Yan','Yang','Bo','Zhi','Kuang','Kuang','You','Fu','Liu','Mie','Cheng','Hui','Chan','Meng','Lan','Huai','Xuan','Rang','Chan','Ji','Ju','Huan','She','Yi')


b=('tim','tib','tibs','tis','tiss','ting','tij','tich','tik','tit','tip','tih','pa','pag','pakk','pags','pan','panj','panh','pad','pal','palg','palm','palb','pals','palt','palp','palh','pam','pab','pabs','pas','pass','pang','paj','pach','pak','pat','pap','pah','pae','paeg','paekk','paegs','paen','paenj','paenh','paed','pael','paelg','paelm','paelb','paels','paelt','paelp','paelh','paem','paeb','paebs','paes','paess','paeng','paej','paech','paek','paet','paep','paeh','pya','pyag','pyakk','pyags','pyan','pyanj','pyanh','pyad','pyal','pyalg','pyalm','pyalb','pyals','pyalt','pyalp','pyalh','pyam','pyab','pyabs','pyas','pyass','pyang','pyaj','pyach','pyak','pyat','pyap','pyah','pyae','pyaeg','pyaekk','pyaegs','pyaen','pyaenj','pyaenh','pyaed','pyael','pyaelg','pyaelm','pyaelb','pyaels','pyaelt','pyaelp','pyaelh','pyaem','pyaeb','pyaebs','pyaes','pyaess','pyaeng','pyaej','pyaech','pyaek','pyaet','pyaep','pyaeh','peo','peog','peokk','peogs','peon','peonj','peonh','peod','peol','peolg','peolm','peolb','peols','peolt','peolp','peolh','peom','peob','peobs','peos','peoss','peong','peoj','peoch','peok','peot','peop','peoh','pe','peg','pekk','pegs','pen','penj','penh','ped','pel','pelg','pelm','pelb','pels','pelt','pelp','pelh','pem','peb','pebs','pes','pess','peng','pej','pech','pek','pet','pep','peh','pyeo','pyeog','pyeokk','pyeogs','pyeon','pyeonj','pyeonh','pyeod','pyeol','pyeolg','pyeolm','pyeolb','pyeols','pyeolt','pyeolp','pyeolh','pyeom','pyeob','pyeobs','pyeos','pyeoss','pyeong','pyeoj','pyeoch','pyeok','pyeot','pyeop','pyeoh','pye','pyeg','pyekk','pyegs','pyen','pyenj','pyenh','pyed','pyel','pyelg','pyelm','pyelb','pyels','pyelt','pyelp','pyelh','pyem','pyeb','pyebs','pyes','pyess','pyeng','pyej','pyech','pyek','pyet','pyep','pyeh','po','pog','pokk','pogs','pon','ponj','ponh','pod','pol','polg','polm','polb','pols','polt','polp','polh','pom','pob','pobs','pos')


b=('yeoss','yeong','yeoj','yeoch','yeok','yeot','yeop','yeoh','ye','yeg','yekk','yegs','yen','yenj','yenh','yed','yel','yelg','yelm','yelb','yels','yelt','yelp','yelh','yem','yeb','yebs','yes','yess','yeng','yej','yech','yek','yet','yep','yeh','o','og','okk','ogs','on','onj','onh','od','ol','olg','olm','olb','ols','olt','olp','olh','om','ob','obs','os','oss','ong','oj','och','ok','ot','op','oh','wa','wag','wakk','wags','wan','wanj','wanh','wad','wal','walg','walm','walb','wals','walt','walp','walh','wam','wab','wabs','was','wass','wang','waj','wach','wak','wat','wap','wah','wae','waeg','waekk','waegs','waen','waenj','waenh','waed','wael','waelg','waelm','waelb','waels','waelt','waelp','waelh','waem','waeb','waebs','waes','waess','waeng','waej','waech','waek','waet','waep','waeh','oe','oeg','oekk','oegs','oen','oenj','oenh','oed','oel','oelg','oelm','oelb','oels','oelt','oelp','oelh','oem','oeb','oebs','oes','oess','oeng','oej','oech','oek','oet','oep','oeh','yo','yog','yokk','yogs','yon','yonj','yonh','yod','yol','yolg','yolm','yolb','yols','yolt','yolp','yolh','yom','yob','yobs','yos','yoss','yong','yoj','yoch','yok','yot','yop','yoh','u','ug','ukk','ugs','un','unj','unh','ud','ul','ulg','ulm','ulb','uls','ult','ulp','ulh','um','ub','ubs','us','uss','ung','uj','uch','uk','ut','up','uh','wo','wog','wokk','wogs','won','wonj','wonh','wod','wol','wolg','wolm','wolb','wols','wolt','wolp','wolh','wom','wob','wobs','wos','woss','wong','woj','woch','wok','wot','wop','woh','we','weg','wekk','wegs','wen','wenj','wenh','wed','wel','welg','welm','welb','wels','welt','welp','welh','wem','web','webs','wes','wess','weng','wej','wech')


b=('poss','pong','poj','poch','pok','pot','pop','poh','pwa','pwag','pwakk','pwags','pwan','pwanj','pwanh','pwad','pwal','pwalg','pwalm','pwalb','pwals','pwalt','pwalp','pwalh','pwam','pwab','pwabs','pwas','pwass','pwang','pwaj','pwach','pwak','pwat','pwap','pwah','pwae','pwaeg','pwaekk','pwaegs','pwaen','pwaenj','pwaenh','pwaed','pwael','pwaelg','pwaelm','pwaelb','pwaels','pwaelt','pwaelp','pwaelh','pwaem','pwaeb','pwaebs','pwaes','pwaess','pwaeng','pwaej','pwaech','pwaek','pwaet','pwaep','pwaeh','poe','poeg','poekk','poegs','poen','poenj','poenh','poed','poel','poelg','poelm','poelb','poels','poelt','poelp','poelh','poem','poeb','poebs','poes','poess','poeng','poej','poech','poek','poet','poep','poeh','pyo','pyog','pyokk','pyogs','pyon','pyonj','pyonh','pyod','pyol','pyolg','pyolm','pyolb','pyols','pyolt','pyolp','pyolh','pyom','pyob','pyobs','pyos','pyoss','pyong','pyoj','pyoch','pyok','pyot','pyop','pyoh','pu','pug','pukk','pugs','pun','punj','punh','pud','pul','pulg','pulm','pulb','puls','pult','pulp','pulh','pum','pub','pubs','pus','puss','pung','puj','puch','puk','put','pup','puh','pwo','pwog','pwokk','pwogs','pwon','pwonj','pwonh','pwod','pwol','pwolg','pwolm','pwolb','pwols','pwolt','pwolp','pwolh','pwom','pwob','pwobs','pwos','pwoss','pwong','pwoj','pwoch','pwok','pwot','pwop','pwoh','pwe','pweg','pwekk','pwegs','pwen','pwenj','pwenh','pwed','pwel','pwelg','pwelm','pwelb','pwels','pwelt','pwelp','pwelh','pwem','pweb','pwebs','pwes','pwess','pweng','pwej','pwech','pwek','pwet','pwep','pweh','pwi','pwig','pwikk','pwigs','pwin','pwinj','pwinh','pwid','pwil','pwilg','pwilm','pwilb','pwils','pwilt','pwilp','pwilh','pwim','pwib','pwibs','pwis','pwiss','pwing','pwij','pwich','pwik','pwit','pwip','pwih','pyu','pyug','pyukk','pyugs','pyun','pyunj','pyunh','pyud','pyul','pyulg','pyulm','pyulb','pyuls','pyult','pyulp','pyulh','pyum','pyub','pyubs','pyus','pyuss','pyung','pyuj','pyuch')


b=('tyal','tyalg','tyalm','tyalb','tyals','tyalt','tyalp','tyalh','tyam','tyab','tyabs','tyas','tyass','tyang','tyaj','tyach','tyak','tyat','tyap','tyah','tyae','tyaeg','tyaekk','tyaegs','tyaen','tyaenj','tyaenh','tyaed','tyael','tyaelg','tyaelm','tyaelb','tyaels','tyaelt','tyaelp','tyaelh','tyaem','tyaeb','tyaebs','tyaes','tyaess','tyaeng','tyaej','tyaech','tyaek','tyaet','tyaep','tyaeh','teo','teog','teokk','teogs','teon','teonj','teonh','teod','teol','teolg','teolm','teolb','teols','teolt','teolp','teolh','teom','teob','teobs','teos','teoss','teong','teoj','teoch','teok','teot','teop','teoh','te','teg','tekk','tegs','ten','tenj','tenh','ted','tel','telg','telm','telb','tels','telt','telp','telh','tem','teb','tebs','tes','tess','teng','tej','tech','tek','tet','tep','teh','tyeo','tyeog','tyeokk','tyeogs','tyeon','tyeonj','tyeonh','tyeod','tyeol','tyeolg','tyeolm','tyeolb','tyeols','tyeolt','tyeolp','tyeolh','tyeom','tyeob','tyeobs','tyeos','tyeoss','tyeong','tyeoj','tyeoch','tyeok','tyeot','tyeop','tyeoh','tye','tyeg','tyekk','tyegs','tyen','tyenj','tyenh','tyed','tyel','tyelg','tyelm','tyelb','tyels','tyelt','tyelp','tyelh','tyem','tyeb','tyebs','tyes','tyess','tyeng','tyej','tyech','tyek','tyet','tyep','tyeh','to','tog','tokk','togs','ton','tonj','tonh','tod','tol','tolg','tolm','tolb','tols','tolt','tolp','tolh','tom','tob','tobs','tos','toss','tong','toj','toch','tok','tot','top','toh','twa','twag','twakk','twags','twan','twanj','twanh','twad','twal','twalg','twalm','twalb','twals','twalt','twalp','twalh','twam','twab','twabs','twas','twass','twang','twaj','twach','twak','twat','twap','twah','twae','twaeg','twaekk','twaegs','twaen','twaenj','twaenh','twaed','twael','twaelg','twaelm','twaelb','twaels','twaelt','twaelp','twaelh','twaem','twaeb','twaebs','twaes','twaess','twaeng','twaej','twaech','twaek','twaet','twaep','twaeh','toe','toeg','toekk','toegs','toen','toenj','toenh','toed','toel','toelg','toelm','toelb')


b=('He','Lan','Biao','Rong','Li','Mo','Bao','Ruo','Lu','La','Ao','Xun','Kuang','Shuo','Liao','Li','Lu','Jue','Liao','Yan','Xi','Xie','Long','Ye','Can','Rang','Yue','Lan','Cong','Jue','Chong','Guan','Ju','Che','Mi','Tang','Lan','Zhu','Lan','Ling','Cuan','Yu','Zhao','Zhao','Pa','Zheng','Pao','Cheng','Yuan','Ai','Wei','Han','Jue','Jue','Fu','Ye','Ba','Die','Ye','Yao','Zu','Shuang','Er','Pan','Chuang','Ke','Zang','Die','Qiang','Yong','Qiang','Pian','Ban','Pan','Chao','Jian','Pai','Du','Chuang','Yu','Zha','Bian','Die','Bang','Bo','Chuang','You','You','Du','Ya','Cheng','Niu','Niu','Pin','Jiu','Mou','Ta','Mu','Lao','Ren','Mang','Fang','Mao','Mu','Gang','Wu','Yan','Ge','Bei','Si','Jian','Gu','You','Ge','Sheng','Mu','Di','Qian','Quan','Quan','Zi','Te','Xi','Mang','Keng','Qian','Wu','Gu','Xi','Li','Li','Pou','Ji','Gang','Zhi','Ben','Quan','Chun','Du','Ju','Jia','Jian','Feng','Pian','Ke','Ju','Kao','Chu','Xi','Bei','Luo','Jie','Ma','San','Wei','Mao','Dun','Tong','Qiao','Jiang','Xi','Li','Du','Lie','Pai','Piao','Bo','Xi','Chou','Wei','Kui','Chou','Quan','Quan','Ba','Fan','Qiu','Ji','Chai','Zhuo','An','Ge','Zhuang','Guang','Ma','You','Kang','Bo','Hou','Ya','Yin','Huan','Zhuang','Yun','Kuang','Niu','Di','Kuang','Zhong','Mu','Bei','Pi','Ju','Yi','Sheng','Pao','Xia','Tuo','Hu','Ling','Fei','Pi','Ni','Yao','You','Gou','Xue','Ju','Dan','Bo','Ku','Xian','Ning','Huan','Hen','Jiao','He','Zhao','Ji','Xun','Shan','Ta','Rong','Shou','Tong','Lao','Du','Xia','Shi','Kuai','Zheng','Yu','Sun','Yu','Bi','Mang','Xi','Juan','Li','Xia','Yin','Suan','Lang','Bei','Zhi','Yan')


b=('Mang','Zhu','Wan','Du','Ji','Jiao','Ba','Suan','Ji','Qin','Zhao','Sun','Ya','Zhui','Yuan','Hu','Hang','Xiao','Cen','Bi','Bi','Jian','Yi','Dong','Shan','Sheng','Da','Di','Zhu','Na','Chi','Gu','Li','Qie','Min','Bao','Tiao','Si','Fu','Ce','Ben','Fa','Da','Zi','Di','Ling','Ze','Nu','Fu','Gou','Fan','Jia','Gan','Fan','Shi','Mao','Po','Ti','Jian','Qiong','Long','Min','Bian','Luo','Gui','Qu','Chi','Yin','Yao','Xian','Bi','Qiong','Kuo','Deng','Xiao','Jin','Quan','Sun','Ru','Fa','Kuang','Zhu','Tong','Ji','Da','Hang','Ce','Zhong','Kou','Lai','Bi','Shai','Dang','Zheng','Ce','Fu','Yun','Tu','Pa','Li','Lang','Ju','Guan','Jian','Han','Tong','Xia','Zhi','Cheng','Suan','Shi','Zhu','Zuo','Xiao','Shao','Ting','Ce','Yan','Gao','Kuai','Gan','Chou','Kuang','Gang','Yun','O','Qian','Xiao','Jian','Pou','Lai','Zou','Bi','Bi','Bi','Ge','Tai','Guai','Yu','Jian','Dao','Gu','Chi','Zheng','Qing','Sha','Zhou','Lu','Bo','Ji','Lin','Suan','Jun','Fu','Zha','Gu','Kong','Qian','Qian','Jun','Chui','Guan','Yuan','Ce','Zu','Bo','Ze','Qie','Tuo','Luo','Dan','Xiao','Ruo','Jian','Xuan','Bian','Sun','Xiang','Xian','Ping','Zhen','Xing','Hu','Yi','Zhu','Yue','Chun','Lu','Wu','Dong','Shuo','Ji','Jie','Huang','Xing','Mei','Fan','Chuan','Zhuan','Pian','Feng','Zhu','Huang','Qie','Hou','Qiu','Miao','Qian','Gu','Kui','Shi','Lou','Yun','He','Tang','Yue','Chou','Gao','Fei','Ruo','Zheng','Gou','Nie','Qian','Xiao','Cuan','Long','Peng','Du','Li','Bi','Zhuo','Chu','Shai','Chi','Zhu','Qiang','Long','Lan','Jian','Bu','Li','Hui','Bi','Di','Cong','Yan','Peng','Can','Zhuan','Pi','Piao','Dou','Yu','Mie','Tuan')


b=('dit','dix','di','dip','diex','die','diep','dat','dax','da','dap','duox','duo','dot','dox','do','dop','dex','de','dep','dut','dux','du','dup','durx','dur','tit','tix','ti','tip','tiex','tie','tiep','tat','tax','ta','tap','tuot','tuox','tuo','tuop','tot','tox','to','top','tex','te','tep','tut','tux','tu','tup','turx','tur','ddit','ddix','ddi','ddip','ddiex','ddie','ddiep','ddat','ddax','dda','ddap','dduox','dduo','dduop','ddot','ddox','ddo','ddop','ddex','dde','ddep','ddut','ddux','ddu','ddup','ddurx','ddur','ndit','ndix','ndi','ndip','ndiex','ndie','ndat','ndax','nda','ndap','ndot','ndox','ndo','ndop','ndex','nde','ndep','ndut','ndux','ndu','ndup','ndurx','ndur','hnit','hnix','hni','hnip','hniet','hniex','hnie','hniep','hnat','hnax','hna','hnap','hnuox','hnuo','hnot','hnox','hnop','hnex','hne','hnep','hnut','nit','nix','ni','nip','niex','nie','niep','nax','na','nap','nuox','nuo','nuop','not','nox','no','nop','nex','ne','nep','nut','nux','nu','nup','nurx','nur','hlit','hlix','hli','hlip','hliex','hlie','hliep','hlat','hlax','hla','hlap','hluox','hluo','hluop','hlox','hlo','hlop','hlex','hle','hlep','hlut','hlux','hlu','hlup','hlurx','hlur','hlyt','hlyx','hly','hlyp','hlyrx','hlyr','lit','lix','li','lip','liet','liex','lie','liep','lat','lax','la','lap','luot','luox','luo','luop','lot','lox','lo','lop','lex','le','lep','lut','lux','lu','lup','lurx','lur','lyt','lyx','ly','lyp','lyrx','lyr','git','gix','gi','gip','giet','giex','gie','giep','gat','gax','ga','gap','guot','guox','guo','guop','got','gox','go','gop','get','gex','ge','gep','gut','gux','gu','gup','gurx','gur','kit','kix','ki','kip','kiex','kie','kiep','kat')


b=('chyess','chyeng','chyej','chyech','chyek','chyet','chyep','chyeh','cho','chog','chokk','chogs','chon','chonj','chonh','chod','chol','cholg','cholm','cholb','chols','cholt','cholp','cholh','chom','chob','chobs','chos','choss','chong','choj','choch','chok','chot','chop','choh','chwa','chwag','chwakk','chwags','chwan','chwanj','chwanh','chwad','chwal','chwalg','chwalm','chwalb','chwals','chwalt','chwalp','chwalh','chwam','chwab','chwabs','chwas','chwass','chwang','chwaj','chwach','chwak','chwat','chwap','chwah','chwae','chwaeg','chwaekk','chwaegs','chwaen','chwaenj','chwaenh','chwaed','chwael','chwaelg','chwaelm','chwaelb','chwaels','chwaelt','chwaelp','chwaelh','chwaem','chwaeb','chwaebs','chwaes','chwaess','chwaeng','chwaej','chwaech','chwaek','chwaet','chwaep','chwaeh','choe','choeg','choekk','choegs','choen','choenj','choenh','choed','choel','choelg','choelm','choelb','choels','choelt','choelp','choelh','choem','choeb','choebs','choes','choess','choeng','choej','choech','choek','choet','choep','choeh','chyo','chyog','chyokk','chyogs','chyon','chyonj','chyonh','chyod','chyol','chyolg','chyolm','chyolb','chyols','chyolt','chyolp','chyolh','chyom','chyob','chyobs','chyos','chyoss','chyong','chyoj','chyoch','chyok','chyot','chyop','chyoh','chu','chug','chukk','chugs','chun','chunj','chunh','chud','chul','chulg','chulm','chulb','chuls','chult','chulp','chulh','chum','chub','chubs','chus','chuss','chung','chuj','chuch','chuk','chut','chup','chuh','chwo','chwog','chwokk','chwogs','chwon','chwonj','chwonh','chwod','chwol','chwolg','chwolm','chwolb','chwols','chwolt','chwolp','chwolh','chwom','chwob','chwobs','chwos','chwoss','chwong','chwoj','chwoch','chwok','chwot','chwop','chwoh','chwe','chweg','chwekk','chwegs','chwen','chwenj','chwenh','chwed','chwel','chwelg','chwelm','chwelb','chwels','chwelt','chwelp','chwelh','chwem','chweb','chwebs','chwes','chwess','chweng','chwej','chwech','chwek','chwet','chwep','chweh','chwi','chwig','chwikk','chwigs','chwin','chwinj','chwinh','chwid','chwil','chwilg','chwilm','chwilb','chwils','chwilt','chwilp','chwilh','chwim','chwib','chwibs','chwis','chwiss','chwing','chwij','chwich')